==> goldly-docs-0.9.40.jar: public/devtools.js <==
(function(){
'use strict';var $Ab,bBb,cBb,dBb,eBb,gBb,hBb,jBb,lBb,mBb,u8,tBb,uBb,vBb,yBb,zBb,ABb,CBb,xBb,nBb,iBb,BBb,aBb,DBb,kBb,oBb,wBb;$Ab=function(a){return $APP.E.F($APP.r(ZAb),a)};bBb=function(a){return new $APP.h(null,2,[$APP.dn,a,$APP.OA,new $APP.H(null,4,5,$APP.I,[$APP.Tab,aBb,$APP.R,a],null)],null)};
cBb=function(){var a=$APP.ri($APP.r(ZAb));$APP.Kj.K($APP.D(["devtools pages:",a]));return new $APP.H(null,2,5,$APP.I,[$APP.loa,new $APP.h(null,3,[$APP.DAb,"Application",$APP.EAb,"/",$APP.LR,$APP.Dh.F(new $APP.H(null,1,5,$APP.I,[new $APP.h(null,3,[$APP.dn,"feedback",$APP.ro,"https://github.com/pink-gorilla/goldly/issues",$APP.BAb,!0],null)],null),$APP.Ni.F(bBb,a))],null)],null)};dBb=function(a){return function(){return new $APP.H(null,2,5,$APP.I,[$APP.bO,a],null)}};
eBb=function(a){var b=$APP.vO.G(dBb("loading page.."));$APP.Rj.F(a,function(c){$APP.Kj.K($APP.D(["devtools page-promise has been resolved!"]));$APP.Kj.K($APP.D(["result: ",c]));return $APP.Kg(b,c)});$APP.Gj.F(a,function(c){$APP.Kj.K($APP.D(["error in resolving devtools page-promise: ",c]));return $APP.Kg(b,dBb(new $APP.H(null,3,5,$APP.I,[$APP.vQa,new $APP.H(null,2,5,$APP.I,[$APP.Ny,"devtools page load error!"],null),new $APP.H(null,2,5,$APP.I,[$APP.wQa,$APP.p.G(c)],null)],null)))});return b};
gBb=function(a){$APP.Kj.K($APP.D(["devtools resolving-page: ",a]));var b=$APP.r(fBb);return b.G?b.G(a):b.call(null,a)};
hBb=function(a){a=$APP.rg(a);var b=$APP.E.F(a,$APP.NS);$APP.E.F(a,$APP.MS);$APP.E.F(a,$APP.HE);var c=function(){var f=$APP.R.G(b);return $APP.m(f)?f:"pinkgorilla"}();c=$APP.Ia(c,"/")?$APP.Gi.F(c,1):c;var d=$Ab(c);$APP.Kj.K($APP.D(["page name: ",c," page-fn: ",d,"route: ",a]));a=gBb(d);var e=$APP.ft(a)?eBb(a):$APP.vO.G(a);return function(f){return new $APP.H(null,2,5,$APP.I,[$APP.r(e),f],null)}};
$APP.rna=function(a){return new $APP.H(null,3,5,$APP.I,[$APP.jna,new $APP.H(null,1,5,$APP.I,[cBb],null),new $APP.H(null,2,5,$APP.I,[hBb,a],null)],null)};$APP.ila=function(a){$APP.Kj.K($APP.D(["setting devtools resolver to webly.spa.resolver .."]));var b=$APP.$q();$APP.Kg(fBb,b);$APP.Kj.K($APP.D(["dev-pages menu has : ",$APP.$e(a)," pages"]));return $APP.Kg(ZAb,a)};jBb=function(a){return new $APP.H(null,2,5,$APP.I,[iBb,a],null)};
lBb=function(a,b,c){return new $APP.H(null,3,5,$APP.I,[$APP.kF,new $APP.h(null,1,[$APP.NC,$APP.dw(a,c)],null),new $APP.H(null,2,5,$APP.I,[kBb,new $APP.h(null,1,[$APP.SS,$APP.dw(b,c)],null)],null)],null)};
mBb=function(a){return new $APP.H(null,4,5,$APP.I,[$APP.Ny,new $APP.H(null,4,5,$APP.I,[lBb,"https://github.com/pink-gorilla/%s/actions?workflow\x3dCI","https://github.com/pink-gorilla/%s/workflows/CI/badge.svg",a],null),new $APP.H(null,4,5,$APP.I,[lBb,"https://codecov.io/gh/pink-gorilla/%s","https://codecov.io/gh/pink-gorilla/%s/branch/master/graph/badge.svg",a],null),new $APP.H(null,4,5,$APP.I,[lBb,"https://clojars.org/org.pinkgorilla/%s","https://img.shields.io/clojars/v/org.pinkgorilla/%s.svg",
a],null)],null)};u8=function(a,b){return $APP.mf(new $APP.H(null,3,5,$APP.I,[$APP.bO,new $APP.H(null,2,5,$APP.I,[nBb,a],null),$APP.Dh.F(new $APP.H(null,1,5,$APP.I,[$APP.bO],null),$APP.Ni.F(mBb,b))],null),new $APP.h(null,1,[$APP.$O,!0],null))};
$APP.Pka=function(a){a=$APP.rg(a);$APP.E.F(a,$APP.NS);$APP.E.F(a,$APP.MS);$APP.E.F(a,$APP.HE);return new $APP.H(null,10,5,$APP.I,[$APP.bO,new $APP.H(null,2,5,$APP.I,[jBb,"devtools"],null),new $APP.H(null,1,5,$APP.I,[oBb],null),new $APP.H(null,2,5,$APP.I,[jBb,"What is pink-gorilla?"],null),new $APP.H(null,4,5,$APP.I,[$APP.tS,new $APP.H(null,2,5,$APP.I,[$APP.uS,"Can run clj code in the browser. This is done via sci interpreter."],null),new $APP.H(null,2,5,$APP.I,[$APP.uS,"Via hiccup-fh (functional hiccup) new render functions can be executed from clj."],
null),new $APP.H(null,2,5,$APP.I,[$APP.uS,"The goldly extension manager will compile your favorite hiccup-fn functions into a precompiled js bundle that is served with goldly"],null)],null),new $APP.H(null,2,5,$APP.I,[jBb,"artefacts"],null),new $APP.H(null,3,5,$APP.I,[u8,"apps and demo",pBb],null),new $APP.H(null,3,5,$APP.I,[u8,"build tools",qBb],null),new $APP.H(null,3,5,$APP.I,[u8,"goldly extensions",rBb],null),new $APP.H(null,3,5,$APP.I,[u8,"notebook (legacy)",sBb],null)],null)};
tBb=function(a){return"number"===typeof a||"string"===typeof a||$APP.Ds(a)||$APP.Es(a)||null==a||a instanceof RegExp||a instanceof $APP.t||a instanceof $APP.G};uBb=function(a){return $APP.Dh.F($APP.qg,$APP.Pg.F($APP.Rk.F(tBb,$APP.ef),$APP.Ni.F(function(b){var c=$APP.Oi.G($APP.uu(b,/[A-Z]/,function(d){return["-",$APP.pt(d)].join("")}));return new $APP.H(null,2,5,$APP.I,[c,a[b]],null)},Object.getOwnPropertyNames(Object.getPrototypeOf(a)))))};
vBb=function(a){return function(){function b(d,e){var f=null;if(1<arguments.length){f=0;for(var k=Array(arguments.length-1);f<k.length;)k[f]=arguments[f+1],++f;f=new $APP.Fe(k,0,null)}return c.call(this,d,f)}function c(d,e){try{d.preventDefault();d.stopPropagation();var f=d.target,k=f.value,l=uBb(f);$APP.Kj.K($APP.D(["eventhandler v:",k," e-norm: ",l," args: ",e]));var q=new $APP.H(null,2,5,$APP.I,[k,l],null),n=null==e?q:$APP.Dh.F($APP.eh,$APP.J.F(q,e));$APP.Kj.K($APP.D(["fun-args: ",n]));return $APP.Zj.F(a,
n)}catch(w){return $APP.Kj.K($APP.D(["eventhandler-fn exception: ",w]))}}b.O=1;b.ba=function(d){var e=$APP.v(d);d=$APP.Je(d);return c(e,d)};b.K=c;return b}()};yBb=function(a){return $APP.Dh.F(new $APP.H(null,1,5,$APP.I,[wBb],null),$APP.Ni.F(function(b){return new $APP.H(null,2,5,$APP.I,[xBb,b],null)},$APP.m(a)?a:$APP.eh))};
zBb=function(a,b,c){var d=function(){var e=$APP.ri(b.G?b.G(a):b.call(null,a));return $APP.m(e)?e:new $APP.H(null,1,5,$APP.I,[c],null)}();return $APP.Dh.F(new $APP.H(null,2,5,$APP.I,[$APP.tn,new $APP.h(null,2,[$APP.yw,c,$APP.EO,vBb(function(e){return $APP.KA(new $APP.H(null,3,5,$APP.I,[$APP.R6a,b,e],null))})],null)],null),$APP.Ni.F(function(e){return new $APP.H(null,3,5,$APP.I,[$APP.GIa,new $APP.h(null,1,[$APP.yw,e],null),$APP.p.G(e)],null)},d))};
ABb=function(a){a=$APP.rg(a);var b=$APP.E.F(a,$APP.sO);a=$APP.E.F(a,$APP.DF);return new $APP.H(null,2,5,$APP.I,[$APP.jP,$APP.Dh.F(new $APP.H(null,2,5,$APP.I,[$APP.kP,new $APP.H(null,3,5,$APP.I,[$APP.hP,new $APP.H(null,2,5,$APP.I,[$APP.iP,"component"],null),new $APP.H(null,2,5,$APP.I,[$APP.iP,"theme"],null)],null)],null),$APP.Ni.F(function(c){var d=$APP.C.J(c,0,null);c=$APP.C.J(c,1,null);return new $APP.H(null,3,5,$APP.I,[$APP.hP,new $APP.H(null,2,5,$APP.I,[$APP.iP,new $APP.H(null,2,5,$APP.I,[$APP.DO,
d],null)],null),new $APP.H(null,2,5,$APP.I,[$APP.iP,zBb(b,d,c)],null)],null)},a))],null)};CBb=function(){var a=$APP.dO.G(new $APP.H(null,1,5,$APP.I,[$APP.u2a],null)),b=$APP.dO.G(new $APP.H(null,1,5,$APP.I,[$APP.pQa],null));return function(){return new $APP.H(null,5,5,$APP.I,[$APP.bO,new $APP.H(null,2,5,$APP.I,[BBb,"components"],null),new $APP.H(null,2,5,$APP.I,[ABb,$APP.r(a)],null),new $APP.H(null,2,5,$APP.I,[BBb,"loaded css"],null),new $APP.H(null,2,5,$APP.I,[yBb,$APP.r(b)],null)],null)}};
$APP.gla=function(a){a=$APP.rg(a);$APP.E.F(a,$APP.NS);$APP.E.F(a,$APP.MS);$APP.E.F(a,$APP.HE);return new $APP.H(null,2,5,$APP.I,[DBb,new $APP.H(null,1,5,$APP.I,[CBb],null)],null)};xBb=new $APP.G(null,"span.m-1","span.m-1",1609723441);nBb=new $APP.G(null,"h1.text-3xl.text-red-400","h1.text-3xl.text-red-400",-15448778);iBb=new $APP.G(null,"h1.text-xl.text-red-900.mt-5","h1.text-xl.text-red-900.mt-5",1774725594);
BBb=new $APP.G(null,"p.mt-5.mb-5.text-purple-600.text-3xl","p.mt-5.mb-5.text-purple-600.text-3xl",1212070121);aBb=new $APP.t("pinkgorilla.devtools.core","devtools-page","pinkgorilla.devtools.core/devtools-page",1075942711,null);DBb=new $APP.G(null,"div.container.mx-auto","div.container.mx-auto",-907582330);kBb=new $APP.G(null,"img.inline-block","img.inline-block",1660842694);oBb=new $APP.G(null,"div.mb-5","div.mb-5",130358228);
wBb=new $APP.G(null,"div.grid.grid-cols-1.md:grid-cols-2","div.grid.grid-cols-1.md:grid-cols-2",1703623111);$APP.ds("devtools");var fBb=$APP.Sk.G(null),ZAb=$APP.Sk.G($APP.qg);var pBb=new $APP.H(null,4,5,$APP.I,["studio","goldly-docs","pages","demo-goldly"],null),qBb=new $APP.H(null,3,5,$APP.I,["modular","webly","goldly"],null),rBb=new $APP.H(null,14,5,$APP.I,"reval ui-repl ui-input ui-site ui-vega ui-highcharts ui-math ui-gorilla ui-quil ui-leaflet ui-cytoscape ui-codemirror ui-markdown ui-binaryclock".split(" "),null),sBb=new $APP.H(null,7,5,$APP.I,"picasso pinkie notebook nrepl-middleware notebook-encoding gorilla-explore kernel-cljs-shadow".split(" "),null);$APP.is();
}).call(this);

==> goldly-docs-0.9.41.jar: public/devtools.js <==
(function(){
'use strict';var $Ab,bBb,cBb,dBb,eBb,gBb,hBb,jBb,lBb,mBb,u8,tBb,uBb,vBb,yBb,zBb,ABb,CBb,xBb,nBb,iBb,BBb,aBb,DBb,kBb,oBb,wBb;$Ab=function(a){return $APP.E.F($APP.r(ZAb),a)};bBb=function(a){return new $APP.h(null,2,[$APP.dn,a,$APP.OA,new $APP.H(null,4,5,$APP.I,[$APP.Pab,aBb,$APP.R,a],null)],null)};
cBb=function(){var a=$APP.ri($APP.r(ZAb));$APP.Kj.K($APP.D(["devtools pages:",a]));return new $APP.H(null,2,5,$APP.I,[$APP.loa,new $APP.h(null,3,[$APP.DAb,"Application",$APP.EAb,"/",$APP.LR,$APP.Dh.F(new $APP.H(null,1,5,$APP.I,[new $APP.h(null,3,[$APP.dn,"feedback",$APP.ro,"https://github.com/pink-gorilla/goldly/issues",$APP.BAb,!0],null)],null),$APP.Ni.F(bBb,a))],null)],null)};dBb=function(a){return function(){return new $APP.H(null,2,5,$APP.I,[$APP.bO,a],null)}};
eBb=function(a){var b=$APP.vO.G(dBb("loading page.."));$APP.Rj.F(a,function(c){$APP.Kj.K($APP.D(["devtools page-promise has been resolved!"]));$APP.Kj.K($APP.D(["result: ",c]));return $APP.Kg(b,c)});$APP.Gj.F(a,function(c){$APP.Kj.K($APP.D(["error in resolving devtools page-promise: ",c]));return $APP.Kg(b,dBb(new $APP.H(null,3,5,$APP.I,[$APP.vQa,new $APP.H(null,2,5,$APP.I,[$APP.Ny,"devtools page load error!"],null),new $APP.H(null,2,5,$APP.I,[$APP.wQa,$APP.p.G(c)],null)],null)))});return b};
gBb=function(a){$APP.Kj.K($APP.D(["devtools resolving-page: ",a]));var b=$APP.r(fBb);return b.G?b.G(a):b.call(null,a)};
hBb=function(a){a=$APP.rg(a);var b=$APP.E.F(a,$APP.NS);$APP.E.F(a,$APP.MS);$APP.E.F(a,$APP.HE);var c=function(){var f=$APP.R.G(b);return $APP.m(f)?f:"pinkgorilla"}();c=$APP.Ia(c,"/")?$APP.Gi.F(c,1):c;var d=$Ab(c);$APP.Kj.K($APP.D(["page name: ",c," page-fn: ",d,"route: ",a]));a=gBb(d);var e=$APP.ft(a)?eBb(a):$APP.vO.G(a);return function(f){return new $APP.H(null,2,5,$APP.I,[$APP.r(e),f],null)}};
$APP.rna=function(a){return new $APP.H(null,3,5,$APP.I,[$APP.jna,new $APP.H(null,1,5,$APP.I,[cBb],null),new $APP.H(null,2,5,$APP.I,[hBb,a],null)],null)};$APP.ila=function(a){$APP.Kj.K($APP.D(["setting devtools resolver to webly.spa.resolver .."]));var b=$APP.$q();$APP.Kg(fBb,b);$APP.Kj.K($APP.D(["dev-pages menu has : ",$APP.$e(a)," pages"]));return $APP.Kg(ZAb,a)};jBb=function(a){return new $APP.H(null,2,5,$APP.I,[iBb,a],null)};
lBb=function(a,b,c){return new $APP.H(null,3,5,$APP.I,[$APP.kF,new $APP.h(null,1,[$APP.NC,$APP.dw(a,c)],null),new $APP.H(null,2,5,$APP.I,[kBb,new $APP.h(null,1,[$APP.SS,$APP.dw(b,c)],null)],null)],null)};
mBb=function(a){return new $APP.H(null,4,5,$APP.I,[$APP.Ny,new $APP.H(null,4,5,$APP.I,[lBb,"https://github.com/pink-gorilla/%s/actions?workflow\x3dCI","https://github.com/pink-gorilla/%s/workflows/CI/badge.svg",a],null),new $APP.H(null,4,5,$APP.I,[lBb,"https://codecov.io/gh/pink-gorilla/%s","https://codecov.io/gh/pink-gorilla/%s/branch/master/graph/badge.svg",a],null),new $APP.H(null,4,5,$APP.I,[lBb,"https://clojars.org/org.pinkgorilla/%s","https://img.shields.io/clojars/v/org.pinkgorilla/%s.svg",
a],null)],null)};u8=function(a,b){return $APP.mf(new $APP.H(null,3,5,$APP.I,[$APP.bO,new $APP.H(null,2,5,$APP.I,[nBb,a],null),$APP.Dh.F(new $APP.H(null,1,5,$APP.I,[$APP.bO],null),$APP.Ni.F(mBb,b))],null),new $APP.h(null,1,[$APP.$O,!0],null))};
$APP.Pka=function(a){a=$APP.rg(a);$APP.E.F(a,$APP.NS);$APP.E.F(a,$APP.MS);$APP.E.F(a,$APP.HE);return new $APP.H(null,10,5,$APP.I,[$APP.bO,new $APP.H(null,2,5,$APP.I,[jBb,"devtools"],null),new $APP.H(null,1,5,$APP.I,[oBb],null),new $APP.H(null,2,5,$APP.I,[jBb,"What is pink-gorilla?"],null),new $APP.H(null,4,5,$APP.I,[$APP.tS,new $APP.H(null,2,5,$APP.I,[$APP.uS,"Can run clj code in the browser. This is done via sci interpreter."],null),new $APP.H(null,2,5,$APP.I,[$APP.uS,"Via hiccup-fh (functional hiccup) new render functions can be executed from clj."],
null),new $APP.H(null,2,5,$APP.I,[$APP.uS,"The goldly extension manager will compile your favorite hiccup-fn functions into a precompiled js bundle that is served with goldly"],null)],null),new $APP.H(null,2,5,$APP.I,[jBb,"artefacts"],null),new $APP.H(null,3,5,$APP.I,[u8,"apps and demo",pBb],null),new $APP.H(null,3,5,$APP.I,[u8,"build tools",qBb],null),new $APP.H(null,3,5,$APP.I,[u8,"goldly extensions",rBb],null),new $APP.H(null,3,5,$APP.I,[u8,"notebook (legacy)",sBb],null)],null)};
tBb=function(a){return"number"===typeof a||"string"===typeof a||$APP.Ds(a)||$APP.Es(a)||null==a||a instanceof RegExp||a instanceof $APP.t||a instanceof $APP.G};uBb=function(a){return $APP.Dh.F($APP.qg,$APP.Pg.F($APP.Rk.F(tBb,$APP.ef),$APP.Ni.F(function(b){var c=$APP.Oi.G($APP.uu(b,/[A-Z]/,function(d){return["-",$APP.pt(d)].join("")}));return new $APP.H(null,2,5,$APP.I,[c,a[b]],null)},Object.getOwnPropertyNames(Object.getPrototypeOf(a)))))};
vBb=function(a){return function(){function b(d,e){var f=null;if(1<arguments.length){f=0;for(var k=Array(arguments.length-1);f<k.length;)k[f]=arguments[f+1],++f;f=new $APP.Fe(k,0,null)}return c.call(this,d,f)}function c(d,e){try{d.preventDefault();d.stopPropagation();var f=d.target,k=f.value,l=uBb(f);$APP.Kj.K($APP.D(["eventhandler v:",k," e-norm: ",l," args: ",e]));var q=new $APP.H(null,2,5,$APP.I,[k,l],null),n=null==e?q:$APP.Dh.F($APP.eh,$APP.J.F(q,e));$APP.Kj.K($APP.D(["fun-args: ",n]));return $APP.Zj.F(a,
n)}catch(w){return $APP.Kj.K($APP.D(["eventhandler-fn exception: ",w]))}}b.O=1;b.ba=function(d){var e=$APP.v(d);d=$APP.Je(d);return c(e,d)};b.K=c;return b}()};yBb=function(a){return $APP.Dh.F(new $APP.H(null,1,5,$APP.I,[wBb],null),$APP.Ni.F(function(b){return new $APP.H(null,2,5,$APP.I,[xBb,b],null)},$APP.m(a)?a:$APP.eh))};
zBb=function(a,b,c){var d=function(){var e=$APP.ri(b.G?b.G(a):b.call(null,a));return $APP.m(e)?e:new $APP.H(null,1,5,$APP.I,[c],null)}();return $APP.Dh.F(new $APP.H(null,2,5,$APP.I,[$APP.tn,new $APP.h(null,2,[$APP.yw,c,$APP.EO,vBb(function(e){return $APP.KA(new $APP.H(null,3,5,$APP.I,[$APP.L6a,b,e],null))})],null)],null),$APP.Ni.F(function(e){return new $APP.H(null,3,5,$APP.I,[$APP.GIa,new $APP.h(null,1,[$APP.yw,e],null),$APP.p.G(e)],null)},d))};
ABb=function(a){a=$APP.rg(a);var b=$APP.E.F(a,$APP.sO);a=$APP.E.F(a,$APP.DF);return new $APP.H(null,2,5,$APP.I,[$APP.jP,$APP.Dh.F(new $APP.H(null,2,5,$APP.I,[$APP.kP,new $APP.H(null,3,5,$APP.I,[$APP.hP,new $APP.H(null,2,5,$APP.I,[$APP.iP,"component"],null),new $APP.H(null,2,5,$APP.I,[$APP.iP,"theme"],null)],null)],null),$APP.Ni.F(function(c){var d=$APP.C.J(c,0,null);c=$APP.C.J(c,1,null);return new $APP.H(null,3,5,$APP.I,[$APP.hP,new $APP.H(null,2,5,$APP.I,[$APP.iP,new $APP.H(null,2,5,$APP.I,[$APP.DO,
d],null)],null),new $APP.H(null,2,5,$APP.I,[$APP.iP,zBb(b,d,c)],null)],null)},a))],null)};CBb=function(){var a=$APP.dO.G(new $APP.H(null,1,5,$APP.I,[$APP.p2a],null)),b=$APP.dO.G(new $APP.H(null,1,5,$APP.I,[$APP.pQa],null));return function(){return new $APP.H(null,5,5,$APP.I,[$APP.bO,new $APP.H(null,2,5,$APP.I,[BBb,"components"],null),new $APP.H(null,2,5,$APP.I,[ABb,$APP.r(a)],null),new $APP.H(null,2,5,$APP.I,[BBb,"loaded css"],null),new $APP.H(null,2,5,$APP.I,[yBb,$APP.r(b)],null)],null)}};
$APP.gla=function(a){a=$APP.rg(a);$APP.E.F(a,$APP.NS);$APP.E.F(a,$APP.MS);$APP.E.F(a,$APP.HE);return new $APP.H(null,2,5,$APP.I,[DBb,new $APP.H(null,1,5,$APP.I,[CBb],null)],null)};xBb=new $APP.G(null,"span.m-1","span.m-1",1609723441);nBb=new $APP.G(null,"h1.text-3xl.text-red-400","h1.text-3xl.text-red-400",-15448778);iBb=new $APP.G(null,"h1.text-xl.text-red-900.mt-5","h1.text-xl.text-red-900.mt-5",1774725594);
BBb=new $APP.G(null,"p.mt-5.mb-5.text-purple-600.text-3xl","p.mt-5.mb-5.text-purple-600.text-3xl",1212070121);aBb=new $APP.t("pinkgorilla.devtools.core","devtools-page","pinkgorilla.devtools.core/devtools-page",1075942711,null);DBb=new $APP.G(null,"div.container.mx-auto","div.container.mx-auto",-907582330);kBb=new $APP.G(null,"img.inline-block","img.inline-block",1660842694);oBb=new $APP.G(null,"div.mb-5","div.mb-5",130358228);
wBb=new $APP.G(null,"div.grid.grid-cols-1.md:grid-cols-2","div.grid.grid-cols-1.md:grid-cols-2",1703623111);$APP.ds("devtools");var fBb=$APP.Sk.G(null),ZAb=$APP.Sk.G($APP.qg);var pBb=new $APP.H(null,4,5,$APP.I,["studio","goldly-docs","pages","demo-goldly"],null),qBb=new $APP.H(null,3,5,$APP.I,["modular","webly","goldly"],null),rBb=new $APP.H(null,14,5,$APP.I,"reval ui-repl ui-input ui-site ui-vega ui-highcharts ui-math ui-gorilla ui-quil ui-leaflet ui-cytoscape ui-codemirror ui-markdown ui-binaryclock".split(" "),null),sBb=new $APP.H(null,7,5,$APP.I,"picasso pinkie notebook nrepl-middleware notebook-encoding gorilla-explore kernel-cljs-shadow".split(" "),null);$APP.is();
}).call(this);
